#
# spec file for package libmygpo-qt5
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libmygpo-qt5
Version:        1.1.0
Release:        2.28
Summary:        Qt Library that wraps the gpodder.net Web API
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            http://wiki.gpodder.org/wiki/Libmygpo-qt
Source0:        http://stefan.derkits.at/files/libmygpo-qt/libmygpo-qt.%{version}.tar.gz
# PATCH-FIX-UPSTREAM -- fix-build-with-qt-5_11.patch
Patch0:         fix-build-with-qt-5_11.patch
BuildRequires:  cmake
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Network)

%description
libmygpo-qt5 is a Qt Library that wraps the gpodder.net Web API (http://wiki.gpodder.org/wiki/Web_Services/API_2)

v1.0 wraps nearly every Request from the gpodder.net API except:
- Simple API Calls Downloading subscription Lists & Uploading subscription Lists
- Retrieving Subscription Changes (you should use "Retrieving Updates for a given Device" instead)

%package -n libmygpo-qt5-1
Summary:        Qt Library that wraps the gpodder.net Web API
Group:          Development/Libraries/C and C++
URL:            http://wiki.gpodder.org/wiki/Libmygpo-qt

%description -n libmygpo-qt5-1
libmygpo-qt5 is a Qt Library that wraps the gpodder.net Web API (http://wiki.gpodder.org/wiki/Web_Services/API_2)

v1.0 wraps nearly every Request from the gpodder.net API except:
- Simple API Calls Downloading subscription Lists & Uploading subscription Lists
- Retrieving Subscription Changes (you should use "Retrieving Updates for a given Device" instead)

%package devel
Summary:        Qt Library that wraps the gpodder.net Web API
Group:          Development/Libraries/C and C++
URL:            http://wiki.gpodder.org/wiki/Libmygpo-qt
Requires:       libmygpo-qt5-1 = %{version}

%description devel
libmygpo-qt5 is a Qt Library that wraps the gpodder.net Web API (http://wiki.gpodder.org/wiki/Web_Services/API_2)

v1.0 wraps nearly every Request from the gpodder.net API except:
- Simple API Calls Downloading subscription Lists & Uploading subscription Lists
- Retrieving Subscription Changes (you should use "Retrieving Updates for a given Device" instead)

%prep
%autosetup -p1 -n libmygpo-qt.%{version}

%build
  %cmake -DMYGPO_BUILD_TESTS=OFF -DINCLUDE_INSTALL_DIR=%{_includedir}/mygpo-qt5/
  %make_jobs

%install
%cmake_install

%post -n libmygpo-qt5-1 -p /sbin/ldconfig
%postun -n libmygpo-qt5-1 -p /sbin/ldconfig

%files devel
%license LICENSE
%{_includedir}/mygpo-qt5/
%{_libdir}/cmake/mygpo-qt5/
%{_libdir}/libmygpo-qt5.so
%{_libdir}/pkgconfig/libmygpo-qt5.pc

%files -n libmygpo-qt5-1
%license LICENSE
%{_libdir}/libmygpo-qt5.so.*

%changelog
* Thu May 24 2018 christophe@krop.fr
- Add fix-build-with-qt-5_11.patch to fix build with Qt >= 5.11
* Tue Apr  3 2018 wbauer@tmo.at
- Update to 1.1.0:
  * Deprecated Qt4 support
  * Improvements in Qt5 support
  * Fix in URL parsing, preventing Double Encoding of URLs
* Mon Feb 26 2018 wbauer@tmo.at
- Update to 1.0.9:
  * Different header installation directories for the qt4 & qt5
    version
  * Bugfix: Top level include_install_dir is now respected
  * Support for QJson 0.7
  * Default to https instead of http
  * Bugfix: Allow setting the server URL
- Tell cmake to install the include files to
  %%{_includedir}/mygpo-qt5/ (which actually is the default but gets
  overridden by the %%cmake macro)
- Drop conflict with libmygqo-qt-devel, there is no overlap anymore
* Thu Nov 13 2014 hrvoje.senjan@gmail.com
- Install license
* Sun Aug 24 2014 hrvoje.senjan@gmail.com
- Activate Qt5 version of libmygpo library: libmygpo-qt5
- Update to 1.0.8:
  * Qt5 support
  * Support for the "Get All Subscriptions" API endpoint
* Sat Apr 13 2013 hrvoje.senjan@gmail.com
- Update to 1.0.7
  * New Config Class. This class allows to programmatically to
    retrieve the libmygpo-qt version and retrieve and set the
    gpodder.net API endpoint
  * Config Class also allows to set a prefix to the user-agent.
  * fixed a bug that created incomplete Episode Actions if an
    Episode Action couldn’t be parsed completely by libmygpo-qt
  * fixed a small bug with the pkgconfig file
  * added support for uploading & retrieving flattr Episode Actions
    to gpodder.net
* Sun Nov 25 2012 nico.kruber@gmail.com
- Fix the SLES build (%%make_install is not expanded on SLES)
* Tue Oct 23 2012 cgiboudeaux@gmx.com
- Update to 1.0.6
  * Added support for DeviceSync API. This API makes it possible to
  set up synchronization with existing gpodder.net devices from inside
  your application
  * Set Contenttype Header to avoid warnings with Qt 4.8
  * Some fixes & enhancements to CMake build system
* Sun Nov 13 2011 cgiboudeaux@gmx.com
- Update to 1.0.5
  * fixed a bug in downloadSubscriptionsJson()
  * changed the way http basic auth information is transmitted to
    gpodder.net to no longer getting annoying popups when using
    libmygpo-qt with KIO from KDE 4.7.X
  * implemented functions to access the new API for retrieving
    synchronization information of devices
  * implemented functions to retrieve toplist and search results in
    gpodders custom XML format
  * added “ConfigStyle” package finding to CMake Buildsystem
* Mon Sep 19 2011 cgiboudeaux@gmx.com
- Update to 1.0.4
  * fixed a bug with an invalid timestamp when uploading EpisodeActions
  * fixed a bug with a wrong url when retrieving EpisodeActions by Podcast
  * fixed a crash happening on MeeGo because of the deletion of QNetworkReply Pointers
* Mon May 23 2011 cgiboudeaux@gmx.com
- Update to 1.0.3
  * All the Private Classes used in libmygpo-qt got their own Header
    Files (name_p.h) instead of having them in the .cpp Files
  * UrlBuilder uses now the fast String Concatenation of Qt
  * Some unneeded Files were removed (RequestHandlerTest &
    tests/Makefile.man)
  * Fixed a Bug in the Build System
  * General Cleanup of unnecessary Includes
* Mon Mar 21 2011 cgiboudeaux@gmx.com
- Add libmygpo-qt, a Qt Library that wraps the gpodder.net Web API
